kibitzr.notifier package
========================

Submodules
----------

kibitzr.notifier.bash module
----------------------------

.. automodule:: kibitzr.notifier.bash
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.notifier.custom module
------------------------------

.. automodule:: kibitzr.notifier.custom
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.notifier.gitter module
------------------------------

.. automodule:: kibitzr.notifier.gitter
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.notifier.mailgun module
-------------------------------

.. automodule:: kibitzr.notifier.mailgun
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.notifier.slack module
-----------------------------

.. automodule:: kibitzr.notifier.slack
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: kibitzr.notifier
    :members:
    :undoc-members:
    :show-inheritance:
